@@ -2,11 +2,11 @@ import datetime
 import json
 import requests
 
-from typing import Callable, List, Union, Dict
+from typing import Callable, List, Union
 
-from .access import LayerToken, AccessGroup, LayerProfile
-from .types import ReturnType, FormatType, MappingType, ObjectType, FieldType
-from .resource import ResourceSchema, ResourceFilter, ResourceOrder, ResourceInstance, ResourceList, Resource
+from .access import LayerToken, LayerProfile
+from .types import ReturnType, FormatType, MappingType, FieldType
+from .resource import ResourceInstance, ResourceList, Resource
 from ..util import JSONVal
 
 
